package jalview.ext.ensembl;

import jalview.datamodel.SequenceFeature;
import jalview.io.gff.SequenceOntology;

public class EnsemblCds extends EnsemblSeqProxy
{
  /*
   * fetch cds features on genomic sequence (to identify the CDS regions)
   * and variation features (to retain)
   */
  private static final EnsemblFeatureType[] FEATURES_TO_FETCH = {
      EnsemblFeatureType.cds, EnsemblFeatureType.variation };

  /**
   * Constructor
   */
  public EnsemblCds()
  {
    super();
  }

  @Override
  public String getDbName()
  {
    return "ENSEMBL (CDS)";
  }

  @Override
  protected EnsemblSeqType getSourceEnsemblType()
  {
    return EnsemblSeqType.CDS;
  }

  @Override
  protected EnsemblFeatureType[] getFeaturesToFetch()
  {
    return FEATURES_TO_FETCH;
  }

  /**
   * Answers true unless the feature type is 'CDS' (or a sub-type of CDS in the
   * Sequence Ontology). CDS features are only retrieved in order to identify
   * the cds sequence range, and are redundant information on the cds sequence
   * itself.
   */
  @Override
  protected boolean retainFeature(String type)
  {
    return !SequenceOntology.getInstance().isA(type, SequenceOntology.CDS);
  }

  /**
   * Answers true if the sequence feature type is 'CDS' (or a subtype of CDS in
   * the Sequence Ontology), and the Parent of the feature is the transcript we
   * are retrieving
   */
  @Override
  protected boolean identifiesSequence(SequenceFeature sf, String accId)
  {
    if (SequenceOntology.getInstance().isA(sf.getType(),
            SequenceOntology.CDS))
    {
      String parentFeature = (String) sf.getValue(PARENT);
      if (("transcript:" + accId).equals(parentFeature))
      {
        return true;
      }
    }
    return false;
  }

}
